==> langsci-0.0.40-py3-none-any.whl: langsci/catalogmetadata.py <==
ONE_LANGUAGE_BOOKS = {
#   ID  ISO6393 Glottocode   Name
    17: ("sje", "pite1240", "Pite Saami"),
    66: ("ybh", "yakk1236", "Yakkha"),
    67: ("mhl", "mauw1238", "Mauwake"),
    78: ("pmy", "papu1250", "Papuan Malay"),
    82: ("phl", "phal1254", "Palula"),
    85: ("fpe", "fern1234", "Pichi"),
    118: ("mlw", "molo1266", "Moloko"),
    124: ("rap", "rapa1244", "Rapa Nui"),
    212: ("tci", "wara1294", "Komnzo"),
    250: ("dar", "sanz1248", "Sanzhi Dargwa"),  #      (Iso is not precise here)
    298: ("gyi", "gyel1242", "Gyeli"),
    295: ("jya", "japh1234", "Japhug"),  # (Iso is not precise here)
    308: ("roh", "surs1245", "Tuatschin"),  # (Iso is not precise here)
    245: ("dga", "sout2789", "Dagaare"),
    98: ("ikx", "ikkk1242", "Ik"),
    326: ("ruc", "ruul1235", "Ruruuli"),
    287: ("nyy", "nyak1261", "Nyakyusa"),
    109: ("nru", "yong1288", "Yongning Na"),
    225: ("dar", "mege1234", "Mehweb"),
    228: ("aaz", "amar1273", "Amarasi"),
    150: ("rus", "russ1263", "Russian"),
    329: ("swe", "swed1254", "Swedish"),
    16: ("ita", "ital1282", "Italian"),
    351: ("fwe", "fwee1238", "Fwe"),
    346: ("eng", "stan1293", "English"),
    344: ("kgv", "kara1499", "Kalamang"),
    324: ("tcu", "sout2972", "Rarámuri"),
}

METALANGUAGE = {
    27: "fra",
    77: "fra",
    143: "fra",
    101: "deu",
    234: "deu",
    155: "deu",
    134: "deu",
    116: "deu",
    160: "por",
    177: "cmn",
    200: "por",
    241: "fra",
    236: "spa",
    340: "deu",
    358: "por",
    371: "deu",
}

LICENSES = {
    148: "CC-BY-SA",
    149: "CC-BY-NC-ND",
    234: "CC-BY-NC-ND",
    359: "CC-BY-SA"
    }

ROMANCE = [236,308,165,27,286,258,16,183,143,200,160,369,358,241,358]


SUPERSEDED = [22, 25, 46, 101, 141, 144, 149, 195, 231, 241, 350, 358, 376, 287 ]

SERIES = {
    "Studies in Diversity Linguistics": "2363-5568",
    "Translation and Multilingual Natural Language Processing": "2364-8899",
    "Textbooks in Language Sciences": "2364-6209",
    "Open Generative Syntax": "2568-7336",
    "Empirically Oriented Theoretical Morphology and Syntax": "2366-3529",
    "Studies in Laboratory Phonology": "2363-5576",
    "Topics at the Grammar-Discourse Interface": "2567-3335",
    "Conceptual Foundations of Language Science": "2363-877X",
    "Language Variation": "2366-7818",
    "History and Philosophy of the Language Sciences": "2629-172X",
    "Contact and Multilingualism": "2700-855X",
    "Contemporary African Linguistics": "2511-7726",
    "Open Slavic Linguistics": "2627-8332",
    "Classics in Linguistics": "2366-374X",
    "African Language Grammars and Dictionaries": "2512-4862",
    "Comprehensive Grammar Library": "2749-7798",
    "Phraseology and Multiword Expressions": "2625-3127",
    "Computational Models of Language Evolution": "2364-7809",
    "EuroSLA Studies": "2626-2665",
    "Studies in Caribbean Languages": "2627-1834",
    "Niger-Congo Comparative Studies": "2627-0048",
    "Morphological Investigations": "2567-742X",
    "Research on Comparative Grammar": "2749-781X",
    "Open Germanic Linguistics": "2750-557X",
    "Languages of the Caucasus": "2699-0156",
    "Open Romance Linguistics": "",
    "Current Issues in Bilingualism": "2747-9927",
    #"Topics in Phonological Diversity": "",
    #"Estudios de Lingüística Amerindia / Estudos de Linguística Ameríndia / Studies of Amerindian Linguistics / Études de Linguistique Amérindienne": "",
    #"Im­ple­ment­ed Gram­mars": "",
    #"Advances in Historical Linguistics" : ""
    }

==> langsci-0.0.41-py3-none-any.whl: langsci/catalogmetadata.py <==
ONE_LANGUAGE_BOOKS = {
#   ID  ISO6393 Glottocode   Name
    17: ("sje", "pite1240", "Pite Saami"),
    66: ("ybh", "yakk1236", "Yakkha"),
    67: ("mhl", "mauw1238", "Mauwake"),
    78: ("pmy", "papu1250", "Papuan Malay"),
    82: ("phl", "phal1254", "Palula"),
    85: ("fpe", "fern1234", "Pichi"),
    118: ("mlw", "molo1266", "Moloko"),
    124: ("rap", "rapa1244", "Rapa Nui"),
    212: ("tci", "wara1294", "Komnzo"),
    250: ("dar", "sanz1248", "Sanzhi Dargwa"),  #      (Iso is not precise here)
    298: ("gyi", "gyel1242", "Gyeli"),
    295: ("jya", "japh1234", "Japhug"),  # (Iso is not precise here)
    308: ("roh", "surs1245", "Tuatschin"),  # (Iso is not precise here)
    245: ("dga", "sout2789", "Dagaare"),
    98: ("ikx", "ikkk1242", "Ik"),
    326: ("ruc", "ruul1235", "Ruruuli"),
    287: ("nyy", "nyak1261", "Nyakyusa"),
    109: ("nru", "yong1288", "Yongning Na"),
    225: ("dar", "mege1234", "Mehweb"),
    228: ("aaz", "amar1273", "Amarasi"),
    150: ("rus", "russ1263", "Russian"),
    329: ("swe", "swed1254", "Swedish"),
    16: ("ita", "ital1282", "Italian"),
    351: ("fwe", "fwee1238", "Fwe"),
    346: ("eng", "stan1293", "English"),
    344: ("kgv", "kara1499", "Kalamang"),
    324: ("tcu", "sout2972", "Rarámuri"),
}

METALANGUAGE = {
    27: "fra",
    77: "fra",
    143: "fra",
    101: "deu",
    234: "deu",
    155: "deu",
    134: "deu",
    116: "deu",
    160: "por",
    177: "cmn",
    200: "por",
    241: "fra",
    236: "spa",
    340: "deu",
    358: "por",
    371: "deu",
}

LICENSES = {
    148: "CC-BY-SA 4.0",
    149: "CC-BY-NC-ND 4.0",
    234: "CC-BY-NC-ND 4.0",
    359: "CC-BY-SA 4.0"
    }

ROMANCE = [236,308,165,27,286,258,16,183,143,200,160,369,358,241,358]


SUPERSEDED = [22, 25, 46, 101, 141, 144, 149, 195, 231, 241, 255, 287, 350, 358, 376]

SERIES = {
    "Studies in Diversity Linguistics": "2363-5568",
    "Translation and Multilingual Natural Language Processing": "2364-8899",
    "Textbooks in Language Sciences": "2364-6209",
    "Open Generative Syntax": "2568-7336",
    "Empirically Oriented Theoretical Morphology and Syntax": "2366-3529",
    "Studies in Laboratory Phonology": "2363-5576",
    "Topics at the Grammar-Discourse Interface": "2567-3335",
    "Conceptual Foundations of Language Science": "2363-877X",
    "Language Variation": "2366-7818",
    "History and Philosophy of the Language Sciences": "2629-172X",
    "Contact and Multilingualism": "2700-855X",
    "Contemporary African Linguistics": "2511-7726",
    "Open Slavic Linguistics": "2627-8332",
    "Classics in Linguistics": "2366-374X",
    "African Language Grammars and Dictionaries": "2512-4862",
    "Comprehensive Grammar Library": "2749-7798",
    "Phraseology and Multiword Expressions": "2625-3127",
    "Computational Models of Language Evolution": "2364-7809",
    "EuroSLA Studies": "2626-2665",
    "Studies in Caribbean Languages": "2627-1834",
    "Niger-Congo Comparative Studies": "2627-0048",
    "Morphological Investigations": "2567-742X",
    "Research on Comparative Grammar": "2749-781X",
    "Open Germanic Linguistics": "2750-557X",
    "Languages of the Caucasus": "2699-0156",
    "Open Romance Linguistics": "",
    "Current Issues in Bilingualism": "2747-9927",
    #"Topics in Phonological Diversity": "",
    #"Estudios de Lingüística Amerindia / Estudos de Linguística Ameríndia / Studies of Amerindian Linguistics / Études de Linguistique Amérindienne": "",
    #"Im­ple­ment­ed Gram­mars": "",
    #"Advances in Historical Linguistics" : ""
    }
